@@ -3,7 +3,7 @@ package LWP::Authen::Digest;
 use strict;
 use base 'LWP::Authen::Basic';
 
-our $VERSION = '6.51';
+our $VERSION = '6.53';
 
 require Digest::MD5;
 
@@ -59,17 +59,7 @@ sub auth_header {
 	@resp{qw(qop cnonce nc)} = ("auth", $cnonce, $nc);
     }
 
-    my(@order) = qw(username realm qop algorithm uri nonce nc cnonce response);
-    if($request->method =~ /^(?:POST|PUT)$/) {
-	$md5->add($request->content);
-	my $content = $md5->hexdigest;
-	$md5->reset;
-	$md5->add(join(":", @digest[0..1], $content));
-	$md5->reset;
-	$resp{"message-digest"} = $md5->hexdigest;
-	push(@order, "message-digest");
-    }
-    push(@order, "opaque");
+    my(@order) = qw(username realm qop algorithm uri nonce nc cnonce response opaque);
     my @pairs;
     for (@order) {
 	next unless defined $resp{$_};
